@@ -284,12 +284,30 @@ class CsrfTokenExtension(Extension):
         return Markup(CsrfTokenNode().render({'csrf_token': csrf_token}))
 
 
+class CaptureExtension(Extension):
+    tags = set(['capture'])
+
+    def parse(self, parser):
+        lineno = parser.stream.next().lineno
+        variable_name = parser.parse_expression()
+        buf = nodes.Name('foo', 'load')
+
+        body = parser.parse_statements(['name:endcapture'], drop_needle=True)
+        content = self.call_method('_capture', [buf])
+        return nodes.CallBlock(content, [], [], body).set_lineno(lineno)
+
+    def _capture(self, buf, caller=None):
+        print '{%s}' % buf
+        return ''
+
 # nicer import names
 load = LoadExtension
 url = URLExtension
 cache = CacheExtension
 spaceless = SpacelessExtension
 csrf_token = CsrfTokenExtension
+capture = CaptureExtension
+
 
 library = Library()
 
@@ -298,3 +316,4 @@ library.extension(url)
 library.extension(cache)
 library.extension(spaceless)
 library.extension(csrf_token)
+library.extension(capture)
