@@ -150,3 +150,15 @@ class TestCacheExtension(TestCase):
         result = env.from_string(
             '{%cache 50*10 "ab" x "foo"%}{{x}}{%endcache%}').render({'x': x})
         self.assertEqual(result, '3')
+
+
+class TestCaptureExtension(TestCase):
+    def test_capture(self):
+        from django_cofingo.extensions import CaptureExtension
+        env = Environment(extensions=[CaptureExtension])
+
+        template = env.from_string(
+            "{% capture 'javascript' %}bar-1{% endcapture %}foo-1"
+            "{% capture 'javascript' %}bar-2{% endcapture %}foo-2"
+            "{{ javascript }}")
+        content = template.render({'buf': 'foo'})
